@@ -1,10 +1,11 @@
 import multicommand
 import logging
 from zabbix_api import ZabbixAPI
+from lib import commands
 
 
 def main():
-    parser = multicommand.create_parser(__import__('commands'))
+    parser = multicommand.create_parser(commands)
     parser.add_argument('-s', '--zbx-server', required=True, help='URL of zabbix server')
     parser.add_argument('-u', '--zbx-user', required=True, help='Zabbix server login username')
     parser.add_argument('-p', '--zbx-passwd', required=True, help='Zabbix server login password')
